@@ -25,9 +25,12 @@ if "__main__" == __name__:
         # raw=True
     )
 
-    print(">" * 30)
-    # print(response)
-    print(response)
-    print("<" * 30)
+    if response.status == "success":
+        tasks = sorted(response.data["tasks"].values(),
+                       key=lambda x: int(x.get("id")))
+
+        print(">" * 30)
+        print(tasks)
+        print("<" * 30)
 
 # end
